@@ -1,11 +1,11 @@
 #
-# $Id: Metabrik.pm,v 0ef34b7a9b91 2015/01/22 06:59:40 gomor $
+# $Id: Metabrik.pm,v 8145485d2318 2015/02/17 06:38:58 gomor $
 #
 package Metabrik;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use base qw(Class::Gomor::Hash);
 
@@ -30,7 +30,7 @@ sub brik_version {
 
 sub brik_properties {
    return {
-      revision => '$Revision: 0ef34b7a9b91 $',
+      revision => '$Revision: 8145485d2318 $',
       tags => [ qw() ],
       attributes => {
          debug => [ qw(0|1) ],
@@ -526,15 +526,18 @@ sub brik_check_require_modules {
       for my $module (keys %$require_modules) {
          eval("require $module;");
          if ($@) {
-            return $self->_log_error("brik_check_require_modules: you have to install Module [$module]");
+            chomp($@);
+            return $self->_log_error("brik_check_require_modules: you have to install ".
+               "Module [$module]: $@");
          }
 
          my @imports = @{$require_modules->{$module}};
          if (@imports > 0) {
             eval('$module->import(@imports);');
             if ($@) {
-               return $self->_log_error("brik_check_require_modules: unable to import functions ".
-                  "[@imports] from Module [$module]: $@");
+            chomp($@);
+               return $self->_log_error("brik_check_require_modules: unable to import ".
+                  "functions [@imports] from Module [$module]: $@");
             }
          }
       }
