@@ -1,17 +1,17 @@
 #
-# $Id: Context.pm,v 7b2aed5215f7 2015/02/10 07:01:25 gomor $
+# $Id: Context.pm,v a81e3d2be39c 2015/02/12 19:29:38 gomor $
 #
 package Metabrik::Core::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 7b2aed5215f7 $',
+      revision => '$Revision: a81e3d2be39c $',
       tags => [ qw(core context main) ],
       attributes => {
          _lp => [ qw(INTERNAL) ],
@@ -153,17 +153,6 @@ sub new {
 sub brik_init {
    my $self = shift;
 
-   my $on_int = sub {
-      $self->debug && $self->log->debug("brik_init: INT captured");
-      if ($self->global->exit_on_sigint) {
-         exit(1);
-      }
-      return 1;
-   };
-
-   $SIG{INT} = $on_int;
-   $SIG{TERM} = $on_int;
-
    my $r = $self->update_available;
    if (! defined($r)) {
       return $self->log->error("brik_init: unable to init Brik [core::context]: ".
@@ -171,7 +160,7 @@ sub brik_init {
       );
    }
 
-   return $self->SUPER::brik_init;
+   return $self->SUPER::brik_init(@_);
 }
 
 sub do {
