@@ -1,5 +1,5 @@
 #
-# $Id: Shell.pm,v 7b2aed5215f7 2015/02/10 07:01:25 gomor $
+# $Id: Shell.pm,v 3a248b5c55a2 2015/02/15 17:11:25 gomor $
 #
 # core::shell Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Core::Shell;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use base qw(Term::Shell Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 7b2aed5215f7 $',
+      revision => '$Revision: 3a248b5c55a2 $',
       tags => [ qw(core main shell) ],
       attributes => {
          echo => [ qw(0|1) ],
@@ -87,20 +87,19 @@ sub new {
 sub brik_init {
    my $self = shift;
 
-   my $context = $self->context;
+   # Allow user to break out of multiline mode or run Commands
+   # Note: Gnu readline() is blocking SIGs, we have to hit enter so 
+   #       Ctrl+C is executed.
+   $SIG{INT} = sub {
+      $self->debug && $self->log->debug("brik_init: INT captured");
+      $self->_update_prompt;
+      if ($self->global->exit_on_sigint) {
+         $self->run_exit;
+      }
+      return 1;
+   };
 
-   $self->debug && $self->log->debug("brik_init: start");
-
-   if ($context->is_used('shell::rc')) {
-      $self->debug && $self->log->debug("brik_init: load rc file");
-
-      my $lines = $context->run('shell::rc', 'load');
-      $self->cmdloop($lines);
-   }
-
-   $self->debug && $self->log->debug("brik_init: done");
-
-   return $self->SUPER::brik_init;
+   return $self->SUPER::brik_init(@_);
 }
 
 sub splash {
@@ -250,12 +249,6 @@ sub init {
 
    $|++;
 
-   $SIG{INT} = sub {
-      $self->debug && $self->log->debug("init: INT caught");
-      $self->run_exit;
-      return 1;
-   };
-
    $self->_update_path_home;
    $self->_update_path_cwd;
    $self->_update_prompt;
@@ -297,11 +290,11 @@ sub cmd_to_code {
    my $self = shift;
    my ($line) = @_;
 
-   if ($line =~ /^\s*set\s+/
-   ||  $line =~ /^\s*get\s+/
-   ||  $line =~ /^\s*use\s+/
-   ||  $line =~ /^\s*run\s+/) {
-      $line =~ s/^\s*(.*)\s*$/\$SHE->cmd("$1");/;
+   while ($line =~ /'\s*(?:use|set|get|run)\s.*?'/) {
+      #$self->log->info("cmd_to_code: before: [$line]");
+      $line =~ s/'\s*((?:use|set|get|run)\s.*?)\s*'/\$SHE->cmd("$1")/;
+      #$self->log->info("cmd_to_code: after: [$line]");
+
       $self->debug && $self->log->debug("cmd_to_code: [$line]");
    }
 
@@ -346,9 +339,6 @@ sub cmdloop {
    my $self = shift;
    my ($lines) = @_;
 
-   $self->{stop} = 0;
-   $self->preloop;
-
    my @lines = ();
 
    # User provided lines to execute (script)
@@ -366,6 +356,9 @@ sub cmdloop {
    }
    # Or we are in interactive mode (shell)
    else {
+      $self->{stop} = 0;
+      $self->preloop;
+
       while (defined(my $line = $self->readline($self->prompt_str))) {
          if ($self->process_line($line, \@lines)) {
             next;   # We are in multiline mode
@@ -376,11 +369,13 @@ sub cmdloop {
 
          last if $self->{stop};
       }
+
+      $self->run_exit;
+
+      return $self->postloop;
    }
 
-   $self->run_exit;
-
-   return $self->postloop;
+   return 1;
 }
 
 #
@@ -478,7 +473,19 @@ sub run_code {
 
    $self->debug && $self->log->debug("run_code: code[$line]");
 
-   my $r = $context->do($line);
+   my $r;
+   eval {
+      # So we can interrupt the do($line) execution
+      local $SIG{INT} = sub {
+         $self->debug && $self->log->debug("run_code: SIG received");
+         if ($self->global->exit_on_sigint) {
+            $self->debug && $self->log->debug("run_code: exiting");
+            $self->run_exit;
+         }
+         die("interrupted by user\n");
+      };
+      $r = $context->do($line);
+   };
    if (! defined($r)) {
       return $self->log->error("run_code: unable to execute Code [$line]");
    }
