@@ -1,5 +1,5 @@
 #
-# $Id: Command.pm,v 100d172795ff 2015/01/19 06:44:55 gomor $
+# $Id: Command.pm,v 24b4b8bc245c 2015/02/26 06:03:56 gomor $
 #
 # shell::command Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Command;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 100d172795ff $',
+      revision => '$Revision: 24b4b8bc245c $',
       tags => [ qw(main shell command system) ],
       attributes => {
          as_array => [ qw(0|1) ],
@@ -24,9 +24,6 @@ sub brik_properties {
          system => [ qw(command) ],
          capture => [ qw(command) ],
       },
-      require_modules => {
-         'IPC::Run' => [ qw(run) ],
-      },
    };
 }
 
@@ -50,8 +47,27 @@ sub system {
       return $self->log->error($self->brik_help_run('system'));
    }
 
-   $cmd = join(' ', $cmd, @args);
-   my $r = CORE::system($cmd);
+   my $command = join(' ', $cmd, @args);
+   my @toks = split(/\s+/, $command);
+   my $bin = $toks[0];
+
+   my @path = split(':', $ENV{PATH});
+   if (! -f $bin) {  # If file is not directly found
+      for my $path (@path) {
+         if (-f "$path/$bin") {
+            $bin = "$path/$bin";
+            last;
+         }
+      }
+   }
+   $toks[0] = $bin;
+
+   if (! -f $bin) {
+      return $self->log->error("system: program [$bin] not found in PATH");
+   }
+
+   $command = join(' ', @toks);
+   my $r = CORE::system($command);
 
    return defined($r) ? 1 : 0;
 }
@@ -64,18 +80,28 @@ sub capture {
       return $self->log->error($self->brik_help_run('capture'));
    }
 
-   my $run = join(' ', $cmd, @args);
+   my $command = join(' ', $cmd, @args);
+   my @toks = split(/\s+/, $command);
+   my $bin = $toks[0];
 
-   #my $out = '';
-   #eval {
-      ## IPC::Run: does not provide string interpolation for shell
-      #IPC::Run::run([ $run ], \undef, \$out);
-   #};
-   #if ($@) {
-      #return $self->log->error("capture: $@");
-   #}
+   my @path = split(':', $ENV{PATH});
+   if (! -f $bin) {  # If file is not directly found
+      for my $path (@path) {
+         if (-f "$path/$bin") {
+            $bin = "$path/$bin";
+            last;
+         }
+      }
+   }
+   $toks[0] = $bin;
 
-   my $out = $self->capture_stderr ? `$run 2>&1` : `$run`;
+   if (! -f $bin) {
+      return $self->log->error("system: program [$bin] not found in PATH");
+   }
+
+   $command = join(' ', @toks);
+
+   my $out = $self->capture_stderr ? `$command 2>&1` : `$command`;
    $out ||= 'undef';
    chomp($out);
    if ($?) {
