@@ -1,5 +1,5 @@
 #
-# $Id: Script.pm,v 7b2aed5215f7 2015/02/10 07:01:25 gomor $
+# $Id: Script.pm,v a81e3d2be39c 2015/02/12 19:29:38 gomor $
 #
 # shell::script Brik
 #
@@ -7,13 +7,13 @@ package Metabrik::Shell::Script;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 use base qw(Metabrik);
 
 sub brik_properties {
    return {
-      revision => '$Revision: 7b2aed5215f7 $',
+      revision => '$Revision: a81e3d2be39c $',
       tags => [ qw(main shell script) ],
       attributes => {
          file => [ qw(file) ],
@@ -22,42 +22,17 @@ sub brik_properties {
          file => 'script.brik',
       },
       commands => {
-         load => [ ],
+         load => [ qw(input_file|OPTIONAL) ],
          exec => [ qw($line_list) ],
       },
    };
 }
 
-sub brik_init {
-   my $self = shift;
-
-   my $context = $self->context;
-   my $shell = $self->shell;
-
-   $self->debug && $self->log->debug("brik_init: start");
-
-   if ($context->is_used('shell::rc')) {
-      $self->debug && $self->log->debug("brik_init: load rc file");
-
-      my $lines = $context->run('shell::rc', 'load');
-      $shell->cmdloop($lines);
-   }
-
-   $self->debug && $self->log->debug("brik_init: done");
-
-   $SIG{INT} = sub {
-      $self->debug && $self->log->debug("brik_init: INT caught");
-      $shell->run_exit;
-      exit(0);
-   };
-
-   return $self->SUPER::brik_init;
-}
-
 sub load {
    my $self = shift;
+   my ($file) = @_;
 
-   my $file = $self->file;
+   $file ||= $self->file;
 
    if (! -f $file) {
       return $self->log->info("load: can't find file [$file]");
